@@ -1,5 +1,22 @@
-def marginal_effects(model, x_test, dv_description, field_labels = None):
-    
+def marginal_effects(model, x_test, dv_description:str, field_labels:dict = None):
+    """
+    Calculates and returns the marginal effects at the mean (MEM) for predcitor fields.
+
+    Ex: gitlabds.marginal_effects(model, x_test, dv_description, field_labels=None):
+
+    Parameters:
+
+    model : model file from training
+
+    x_test : test "predictors" dataframe. If using mars_modeling, this is output containing only the columned used in the model (e.g. x_test_pared)
+
+    dv_description : Description of the outcome field to be used in text-based insights.
+
+    field_labels : Dict of field descriptions. The key is the field/feature/predictor name. The value is descriptive text of the field. This field is optional and by default will use the field name
+
+
+    Returns a Dataframe of marginal effects.
+    """
     import pandas as pd
     import numpy as np
     
@@ -236,7 +253,36 @@ def marginal_effects(model, x_test, dv_description, field_labels = None):
     return bf
 
 
-def prescriptions(model, input_df, scored_df, actionable_fields, dv_description, field_labels=None, returned_insights=5, only_actionable=False, explanation_fields='all'):
+def prescriptions(model, input_df, scored_df, actionable_fields:dict, dv_description:str, field_labels=None, returned_insights:int=5, only_actionable:bool=False, explanation_fields='all'):
+
+    """
+    Return "actionable" prescriptions and explanatory insights for each scored record. Insights first list actionable prescriptions follow by explainatory insights. This approach is recommended or linear/logistic methodologies only. Caution should be used if using a black box approach, as manpulating more than one prescription at a time could change a record's model score in unintended ways.
+
+    Ex: gitlabds.prescriptions(model, input_df, scored_df, actionable_fields, dv_description, field_labels=None, returned_insights=5, only_actionable=False, explanation_fields='all'):
+
+    Parameters:
+
+
+    model : model file from training
+
+    input_df : train "predictors" dataframe. If using mars_modeling, this is output containing only the columned used in the model (e.g. x_trained_pared)
+
+    scored_df : dataframe containing model scores.
+
+    actionable_fields : Dict of actionable fields. The key is the field/feature/predictor name. The value accepts one of 3 values: Increasing for prescriptions only when the field increases; Decreasing for prescriptions only when the field decreases; Both for when the field either increases or decreases.
+
+    dv_description : Description of the outcome field to be used in text-based insights.
+
+    field_labels : Dict of field descriptions. The key is the field/feature/predictor name. The value is descriptive text of the field. This field is optional and by default will use the field name
+
+    returned_insights : Number of insights per record to return. Defaults to 5
+
+    only_actionable : Only return actionable prescriptions
+
+    explanation_fields : List of explainable (non-actionable insights) fields to return insights for. Defaults to 'all' for all fields.
+
+
+    Returns a Dataframe of prescriptive actions. One row per record input."""
 
     import pandas as pd
     import numpy as np
@@ -404,7 +450,7 @@ def prescriptions(model, input_df, scored_df, actionable_fields, dv_description,
     change_score = change_score[(change_score['effect_pct_abs'] > 0.0051)]
         
     #Sort by index (asc), type (asc), absoulte value of effect (desc)
-    change_score.sort_values(by=[change_score.index.name, 'type', 'effect_pct_abs'], axis=0, ascending=(True, True, False), inplace=True)
+    change_score.sort_values(by=['type', 'effect_pct_abs'], axis=0, ascending=(True, False), inplace=True)
     
     #Add on Feature Labels
     if field_labels:
@@ -465,9 +511,9 @@ def prescriptions(model, input_df, scored_df, actionable_fields, dv_description,
     change_score = change_score[['feature', 'type', 'effect', 'effect_pct', 'insight']]   
 
     #limit to number of insights as defined by 'returned_insights'
-    change_score = change_score.groupby(change_score.index.name).head(returned_insights)
+    change_score = change_score.groupby(change_score.index).head(returned_insights)
     
     #Aggregate to index-level, collasping index to one line
-    scores_w_insights = change_score.groupby([change_score.index.name])['insight'].apply(' '.join)
+    scores_w_insights = change_score.groupby([change_score.index])['insight'].apply(' '.join)
         
-    return scores_w_insights 
\ No newline at end of file
+    return scores_w_insights 
